@@ -587,7 +587,7 @@ class InstallApp(BaseApp, InstallSettingsMixin, InstallSummarizerMixin, ConfigGe
     def configDNSAndCertsRoute53(self):
         self.setParam("dns_provider", "route53")
         self.printDescription([
-            "Provide your AWS account access key ID & secret access key",
+            "Provide your AWS account access key ID and secret access key",
             "This will be used to authenticate into the AWS account where your AWS Route 53 hosted zone instance is located",
             ""
         ])
@@ -632,12 +632,9 @@ class InstallApp(BaseApp, InstallSettingsMixin, InstallSummarizerMixin, ConfigGe
             if not self.getParam("mas_channel").startswith("8.") and not self.getParam("mas_channel").startswith("9.0"):
                 self.installManage = True
                 self.isManageFoundation = True
-                self.setParam("is_full_manage", "false")
                 self.setParam("mas_app_settings_aio_flag", "false")
                 self.manageAppName = "Manage foundation"
                 self.printDescription([f"{self.manageAppName} installs the following capabilities: User, Security groups, Application configurator and Mobile configurator."])
-        else:
-            self.setParam("is_full_manage", "true")
 
         if self.installManage:
             self.configAppChannel("manage")
@@ -1113,9 +1110,6 @@ class InstallApp(BaseApp, InstallSettingsMixin, InstallSummarizerMixin, ConfigGe
                 self.fatalError(f"Unknown option: {key} {value}")
 
         if self.installManage:
-            # If Manage is being installed and --is-full-manage was set to something different than "false", assume it is "true"
-            if self.getParam("is_full_manage") != "false":
-                self.setParam("is_full_manage", "true")
 
             # Configure Storage and Access mode
             self.manageStorageAndAccessMode()
@@ -1143,6 +1137,14 @@ class InstallApp(BaseApp, InstallSettingsMixin, InstallSummarizerMixin, ConfigGe
             self.validateCatalogSource()
             self.licensePrompt()
 
+        # Version before 9.1 cannot have empty components
+        if (self.getParam("mas_channel").startswith("8.") or self.getParam("mas_channel").startswith("9.0")) and self.getParam("mas_appws_components") == "":
+            self.fatalError("--mas_appws_components must be set for versions earlier than 9.1.0")
+
+        #  An error should be raised if "health" is not specified when installing Predict.
+        if ((self.getParam("mas_app_channel_predict") is not None and self.getParam("mas_app_channel_predict") != "") and 'health' not in self.getParam("mas_appws_components")):
+            self.fatalError("--mas_appws_components must include 'health' component when installing Predict")
+
     @logMethodCall
     def install(self, argv):
         """
@@ -1268,7 +1270,7 @@ class InstallApp(BaseApp, InstallSettingsMixin, InstallSummarizerMixin, ConfigGe
                 )
                 prepareInstallSecrets(
                     dynClient=self.dynamicClient,
-                    instanceId=self.getParam("mas_instance_id"),
+                    namespace=pipelinesNamespace,
                     slsLicenseFile=self.slsLicenseFileSecret,
                     additionalConfigs=self.additionalConfigsSecret,
                     podTemplates=self.podTemplatesSecret,
