@@ -346,11 +346,6 @@ masAppsArgGroup.add_argument(
     required=False,
     help="Subscription channel for Maximo Manage"
 )
-masAppsArgGroup.add_argument(
-    "--is-full-manage",
-    required=False,
-    help="Full Manage instead of Manage Foundation"
-)
 masAppsArgGroup.add_argument(
     "--predict-channel",
     required=False,
@@ -442,7 +437,7 @@ manageArgGroup.add_argument(
     dest="mas_appws_components",
     required=False,
     help="Set Manage Components to be installed (e.g 'base=latest,health=latest,civil=latest')",
-    default="base=latest,health=latest"
+    default=""
 )
 
 manageArgGroup.add_argument(
@@ -550,6 +545,15 @@ manageArgGroup.add_argument(
     help="Manage server timezone. Default is `GMT`"
 )
 
+manageArgGroup.add_argument(
+    "--manage-upgrade-type",
+    dest="mas_appws_upgrade_type",
+    required=False,
+    help="Set Manage upgrade type. Default is `regularUpgrade`",
+    default="regularUpgrade",
+    choices=["regularUpgrade", "onlineUpgrade"]
+)
+
 # Manage Attachments
 # -----------------------------------------------------------------------------
 manageArgGroup.add_argument(
